#!/bin/sh
WHERE_TO_STORE=$1
ACAP_NOW_DAY=$(date +"%Y-%m-%d")
ACAP_NOW_TIME=$(date +"%H:%M:%S")

ACAP_TMP_DATA=.datajson
ACAP_TMP_OLD_DATA=.olddatajson
ACAP_APPS_DATA=.appsjson

if [ ! -n "$WHERE_TO_STORE" ]; then
  # A storage path needs to have been given
  echo "usage: acap_status_monitor.sh destination"

else

  if [ -f $WHERE_TO_STORE/$ACAP_TMP_DATA ]; then
    mv $WHERE_TO_STORE/$ACAP_TMP_DATA $WHERE_TO_STORE/$ACAP_TMP_OLD_DATA
  fi

  for i in $(ls /usr/local/packages | sort); do

    if [ -d /usr/local/packages/$i ]; then

      if cd /usr/local/packages/$i; then

        if [ -f /usr/local/packages/$i/package.conf ] && [ -f /usr/local/packages/$i/conf/runstate.conf ]; then

          . /usr/local/packages/$i/package.conf
          . /usr/local/packages/$i/conf/runstate.conf

          if [ -f is_running ]; then

            ENABLED=$(cat is_running)

          fi

          if [ -n "$ENABLED" ] && [ -n "$APPNAME" ]; then

            if dbus-send --system --print-reply --dest=com.axis.RuleEngine --type=method_call /com/axis/RuleEngine com.axis.RuleEngine.ListAllApplications | grep "$APPNAME" >/dev/null; then

              ENABLED="Idle"

            fi

          fi

        fi

      fi

      if [ -n "$PACKAGENAME" ] && [ -n "$ENABLED" ] && [ -n "$APPNAME" ] &&  [ "$APPNAME" != "Support_ACAP" ]; then

        # Stores the running status for all ACAPs except itself.

        printf "{\"packagename\":\"$PACKAGENAME\",\"appname\":\"$APPNAME\"}\n" >> $WHERE_TO_STORE/$ACAP_TMP_DATA

        if [ "$ENABLED" == "no" ]; then
          ENABLED="Stopped"
        fi

        if [ "$ENABLED" == "yes" ]; then
          ENABLED="Running"
        fi

        if [ ! -f $WHERE_TO_STORE/$APPNAME.csv ]; then
          printf "Date,Time,Package Name,Status\r\n" > $WHERE_TO_STORE/$APPNAME.csv
        fi

        printf "$ACAP_NOW_DAY,$ACAP_NOW_TIME,$PACKAGENAME,$ENABLED\r\n" >> $WHERE_TO_STORE/$APPNAME.csv

      fi

    fi

  done

  if [ -f $WHERE_TO_STORE/$ACAP_TMP_OLD_DATA ]; then
    cat $WHERE_TO_STORE/$ACAP_TMP_DATA $WHERE_TO_STORE/$ACAP_TMP_OLD_DATA | sort | uniq > $WHERE_TO_STORE/$ACAP_TMP_DATA
    rm $WHERE_TO_STORE/$ACAP_TMP_OLD_DATA
  fi

  printf "[" > "$WHERE_TO_STORE/$ACAP_APPS_DATA"

  FIRST_LINE_READ=1
  while read line; do

    if [ $FIRST_LINE_READ -eq 1 ]; then
      printf "$line" >> "$WHERE_TO_STORE/$ACAP_APPS_DATA"
    else
      printf ",$line" >> "$WHERE_TO_STORE/$ACAP_APPS_DATA"
    fi

    FIRST_LINE_READ=0

  done < $WHERE_TO_STORE/$ACAP_TMP_DATA

  if [ -f "$WHERE_TO_STORE/$ACAP_APPS_DATA" ]; then
    printf "]" >> $WHERE_TO_STORE/$ACAP_APPS_DATA
  fi

fi

exit 0
