#!/bin/sh
#
# Glob some paths and look for "signature" files.
# monitory_creator.sh creates the signature file
# and deactive_monitor_session() adds an "End:" line.
# If there is no "End:" found in the signature file,
# the session is considered "broken".
# The found sessions are printed to the files
# found_monitoring_sessions.txt and
# lost_monitoring_sessions.txt (the "broken" ones).


MON_SERIAL=$1 # The serial number of the device

MON_HOME_FLASH_DIR=/usr/local/packages/Support_ACAP/localdata

MON_FILENAME=found_monitoring_sessions.txt
MON_LOST_FILENAME=lost_monitoring_sessions.txt

MON_SIGNATURE_FILE_NAME=.signature
MON_OLD_SIGNATURE_FILE_NAME=signature.txt

copy_signature_files() {
  local signature_glob="$1"
  local signature_file_name="$2"

  for signature in $(ls $signature_glob/$signature_file_name); do
    echo "PATH:${signature%/$signature_file_name}" >> "$MON_HOME_FLASH_DIR/tmp.txt"
    end=0
    while read line; do
      echo "$line" >> "$MON_HOME_FLASH_DIR/tmp.txt"
      if [ "$line" == "End:" ]; then
      end=1
      fi
    done < $signature

    if [ $end -eq 1 ]; then
      cat "$MON_HOME_FLASH_DIR/tmp.txt" >> "$MON_HOME_FLASH_DIR/$MON_FILENAME"
    else
      cat "$MON_HOME_FLASH_DIR/tmp.txt" >> "$MON_HOME_FLASH_DIR/$MON_LOST_FILENAME"
    fi

    rm "$MON_HOME_FLASH_DIR/tmp.txt"
  done
}

echo "Collected sessions at $(date)" > "$MON_HOME_FLASH_DIR/$MON_FILENAME"
echo "Collected sessions at $(date)" > "$MON_HOME_FLASH_DIR/$MON_LOST_FILENAME"

if [ ! -z "$MON_SERIAL" ]; then
  # Serial number was provided so we will only copy sessions from that serial number.

  copy_signature_files "/var/spool/storage/*/Support_ACAP_$MON_SERIAL/*" "$MON_SIGNATURE_FILE_NAME"

  # Finding the internal sessions
  copy_signature_files "/usr/local/packages/Support_ACAP/localdata/*" "$MON_SIGNATURE_FILE_NAME"

	# Signature file had the name: "signature.txt" before it was changed to ".signature".
	# This for loop is to collect these old sessions aswell.
  copy_signature_files "/var/spool/storage/*/Support_ACAP_$MON_SERIAL/*" "$MON_OLD_SIGNATURE_FILE_NAME"
else
	# Collect all sessions no matter where they are from

  copy_signature_files "/var/spool/storage/*/Support_ACAP_*/*" "$MON_SIGNATURE_FILE_NAME"

	# Collect all sessions from the zip
  copy_signature_files "/var/spool/storage/*/*Support_ACAP_*" "$MON_SIGNATURE_FILE_NAME"

	# Signature file had the name: "signature.txt" before it was changed to ".signature".
	# This for loop is to collect these old sessions aswell.
  copy_signature_files "/var/spool/storage/*/Support_ACAP_*/*" "$MON_OLD_SIGNATURE_FILE_NAME"

	# Collect all sessions from the zip
  copy_signature_files "/var/spool/storage/*/*Support_ACAP_*" "$MON_OLD_SIGNATURE_FILE_NAME"
fi
