#!/bin/sh

# Stores Network Device Test rule in a text file, which is read on reboot.

set -e

if [ "$#" -ne 5 ]; then
  >&2 echo "Expected 5 parameters, got $#"
  >&2 echo "Usage: ./define_nc_rule.sh IP PORT INTERVAL MAX_FAILS NAME"
  exit 1
fi

rule_ip="$1"
rule_port="$2"
rule_timer="$3"
rule_fails="$4"
rule_name="$5"

cd /usr/local/packages/Support_ACAP/localdata
if [ "$?" -ne "0" ]; then
  >&2 echo "Could not change directory, does it exist?"
  exit 1
fi

# It should not be possible to enter the units own address.
ip -f inet address |
grep inet |
cut -d' ' -f6 |
cut -d'/' -f1 |
while read line; do
  if [ "$rule_ip" == "$line" ]; then
    >&2 echo "The entered IP: $rule_ip collided with IP: $line, so no new rule was declared."
    exit 1
  fi
done
[ "$?" != "0" ] && exit $?

echo "N:$rule_ip" >> nc_rules.txt
echo "P:$rule_port"  >> nc_rules.txt
echo "T:$rule_timer" >> nc_rules.txt
echo "F:$rule_fails" >> nc_rules.txt
echo "I:$rule_name" >> nc_rules.txt
