#!/bin/sh

MON_SECONDARY_STORAGE="$1"
MON_SERIAL_NUMBER="$2"
MON_ACTIVITY_FOLDER="$3"
MON_TIME_START="$4"
MON_CAPTURE_INTERVAL="$5"
MON_ADVANCED_DEBUG="$6"

MON_SIGNATURE_FILE_NAME=.signature

MON_CURRENT_DESCRIPTOR=/usr/local/packages/Support_ACAP/localdata/current_monitoring_session.txt

create_directory() {
  mkdir "$1"
  chmod a+rw "$1"
}

if [ "$MON_SECONDARY_STORAGE" = "localdata" ]; then
  # This is an internal storage session
  MON_DIR="/usr/local/packages/Support_ACAP/$MON_SECONDARY_STORAGE/$MON_ACTIVITY_FOLDER"

  if [ ! -d "$MON_DIR" ]; then
    create_directory "$MON_DIR"
    create_directory "$MON_DIR/system_monitoring"

    # storing a signature of this monitoring session
    echo "Monitoring:" > "$MON_DIR/$MON_SIGNATURE_FILE_NAME"
    chmod a+rw "$MON_DIR/$MON_SIGNATURE_FILE_NAME"

    create_directory "$MON_DIR/system_monitoring/monitoring_basic"

    printf "----- System log ----- \r\n" > "$MON_DIR/system_monitoring/monitoring_basic/Continuous_Syslog.txt"

    create_directory "$MON_DIR/system_monitoring/monitoring_basic/Server_Reports"

    echo "syslog files" >> "$MON_DIR/$MON_SIGNATURE_FILE_NAME"

    create_directory "$MON_DIR/system_monitoring/monitoring_vapix"

    if ls /etc/ws/onvif &>/dev/null; then
      create_directory "$MON_DIR/system_monitoring/monitoring_onvif"
      echo "onvif media.conf monitoring" >> "$MON_DIR/$MON_SIGNATURE_FILE_NAME"
    fi

    create_directory "$MON_DIR/system_monitoring/monitoring_devicetest"
    echo "devicetest monitoring" >> "$MON_DIR/$MON_SIGNATURE_FILE_NAME"

    create_directory "$MON_DIR/system_monitoring/monitoring_metadata"
    echo "metadata monitoring" >> "$MON_DIR/$MON_SIGNATURE_FILE_NAME"

    echo "Start:" >> "$MON_DIR/$MON_SIGNATURE_FILE_NAME"
    date >> "$MON_DIR/$MON_SIGNATURE_FILE_NAME"

    echo "SECS:$MON_SECONDARY_STORAGE" > "$MON_CURRENT_DESCRIPTOR"
    echo "ACTI:$MON_ACTIVITY_FOLDER" >> "$MON_CURRENT_DESCRIPTOR"
    echo "TIME:$MON_TIME_START" >> "$MON_CURRENT_DESCRIPTOR"
    echo "CAPT:$MON_CAPTURE_INTERVAL" >> "$MON_CURRENT_DESCRIPTOR"
  fi
else
  MON_ACAP_DIR="/var/spool/storage/$MON_SECONDARY_STORAGE/Support_ACAP_$MON_SERIAL_NUMBER"
  if [ ! -d "$MON_ACAP_DIR" ]; then
    create_directory "$MON_ACAP_DIR"
  fi

  MON_DIR="$MON_ACAP_DIR/$MON_ACTIVITY_FOLDER"
  if [ ! -d "$MON_DIR" ]; then
    create_directory "$MON_DIR"
  fi

  if [ ! -d "$MON_DIR/system_monitoring" ]; then
    create_directory "$MON_DIR/system_monitoring"
  fi

  # storing a signature of this monitoring session
  echo "Monitoring:" > "$MON_DIR/$MON_SIGNATURE_FILE_NAME"
  chmod a+rw "$MON_DIR/$MON_SIGNATURE_FILE_NAME"

  # Folder always reserved for coredumps
  create_directory "$MON_DIR/coredumps"

  # Folder always reserved for meminfo
  create_directory "$MON_DIR/system_monitoring/monitoring_meminfo"

  create_directory "$MON_DIR/system_monitoring/monitoring_basic"

  printf "----- System log ----- \r\n" > "$MON_DIR/system_monitoring/monitoring_basic/Continuous_Syslog.txt"

  create_directory "$MON_DIR/system_monitoring/monitoring_basic/Server_Reports"

  create_directory "$MON_DIR/system_monitoring/monitoring_acap"

  case $(parhandclient --nolog get root.Properties.Radar.Radar) in
    '"yes"')
      create_directory "$MON_DIR/system_monitoring/monitoring_radar"
      ;;
  esac

  if ls /etc | grep "apache2" >/dev/null; then
    create_directory "$MON_DIR/system_monitoring/monitoring_vapix"

    printf "----- HTTP Server ----- \r\n" > "$MON_DIR/system_monitoring/monitoring_basic/HTTP_log.txt"

    create_directory "$MON_DIR/system_monitoring/monitoring_vapix/logfiles"
    create_directory "$MON_DIR/system_monitoring/monitoring_vapix/others"
  fi

  if ls /etc/ws/onvif &>/dev/null; then
    create_directory "$MON_DIR/system_monitoring/monitoring_onvif"
    echo "onvif media.conf monitoring" >> "$MON_DIR/$MON_SIGNATURE_FILE_NAME"
  fi

  echo "syslog files" >> "$MON_DIR/$MON_SIGNATURE_FILE_NAME"

  create_directory "$MON_DIR/system_monitoring/monitoring_load"
  echo "load average (15 min)" >> "$MON_DIR/$MON_SIGNATURE_FILE_NAME"

  create_directory "$MON_DIR/system_monitoring/monitoring_streams"
  echo "stream history" >> "$MON_DIR/$MON_SIGNATURE_FILE_NAME"

  create_directory "$MON_DIR/system_monitoring/monitoring_network"
  echo "network bandwidth" >> "$MON_DIR/$MON_SIGNATURE_FILE_NAME"

  create_directory "$MON_DIR/system_monitoring/monitoring_kernel"
  echo "kernel monitoring" >> "$MON_DIR/$MON_SIGNATURE_FILE_NAME"

  create_directory "$MON_DIR/system_monitoring/monitoring_devicetest"
  echo "devicetest monitoring" >> "$MON_DIR/$MON_SIGNATURE_FILE_NAME"

  create_directory "$MON_DIR/system_monitoring/monitoring_metadata"
  echo "metadata monitoring" >> "$MON_DIR/$MON_SIGNATURE_FILE_NAME"

  echo "Start:" >> "$MON_DIR/$MON_SIGNATURE_FILE_NAME"
  date >> "$MON_DIR/$MON_SIGNATURE_FILE_NAME"

  echo "SECS:$MON_SECONDARY_STORAGE" > "$MON_CURRENT_DESCRIPTOR"
  echo "ACTI:$MON_ACTIVITY_FOLDER" >> "$MON_CURRENT_DESCRIPTOR"
  echo "TIME:$MON_TIME_START" >> "$MON_CURRENT_DESCRIPTOR"
  echo "CAPT:$MON_CAPTURE_INTERVAL" >> "$MON_CURRENT_DESCRIPTOR"

  if [ -n "$MON_ADVANCED_DEBUG" ]; then
    echo "CRAS:$MON_ADVANCED_DEBUG" >> "$MON_CURRENT_DESCRIPTOR"
  fi
fi
