#!/bin/sh

# Used to monitor processess
# VmRSS = progres (in vmstatus.sh) * 4 (the size of pages)) kB
# VmSize = totres (in vmstatus) * 4 (the size of pages) kB
# Name = processes name
# Pid = processes pid

# Secondary storage should point to /var/spool/storage/.../.../load
MON_SECONDARY_STORAGE="$1"

now_day=$(date +"%Y-%m-%d")
now_time=$(date +"%H:%M:%S")

topcommand="top -bn1"

val=0
num_VSZ=100
num_PVSZ=100
num_CPU=100
num_COMMAND=100
num_PID=100

first_found=0

printf %s "$($topcommand)" | while read -r line; do

  line="$(echo -e "${line}" | sed -e 's/^[[:space:]]*//')"
  val=$((val+1))

  if [ "$first_found" -eq 0 ]; then

    if [ "$(echo $line | grep -c PID)" -gt 0 ]; then
      # iterate to identify which column corresponds to which command, since column formatting depends on configuration and might differ
      col=1

      while [ $col -lt 20 ]; do
        identifier="$(echo "$line" | tr -s ' '| cut -d ' ' -f $col)"
        if [ "$identifier" = 'VSZ' ]; then
          num_VSZ=$col
        fi
        if [ "$identifier" = '%VSZ' ]; then
          num_PVSZ=$col
        fi
        if [ "$identifier" = '%CPU' ]; then
          num_CPU=$col
        fi
        if [ "$identifier" = 'COMMAND' ]; then
          num_COMMAND=$col
        fi
        if [ "$identifier" = 'PID' ]; then
          num_PID=$col
          first_found=1
        fi

        col=$((col+1))
      done
    fi

    continue
  fi

  if [ "$num_VSZ" -eq 100 ] || [ "$num_PVSZ" -eq 100 ] || [ "$num_CPU" -eq 100 ] || [ "$num_COMMAND" -eq 100 ] || [ "$num_PID" -eq 100 ]; then
    # Could not find one or more of the needed columns
    break;
  fi

  p_name=$(echo "$line" | tr -s ' ' |  cut -d ' ' -f ${num_COMMAND}-)
  p_pid=$(echo "$line" | tr -s ' ' | cut -d ' ' -f $num_PID)

  if [ -z "$p_name" ] || [ -z "$p_pid" ]; then
    # process name or pid is empty
    continue;
  fi

  if [ "$p_name" == "$topcommand" ]; then
    # Skip this process
    continue;
  fi

  if [ "$(echo "$p_name" | cut -c1)" != "/" ]; then
    # Only store for processes starting with /
    continue;
  fi

  p_bin_name="$(echo "${p_name%% *}" | grep -o '[^/]*$')"
  if [ -z "$p_bin_name" ]; then
    # Could not get the binary name (does it end with a slash? or start with a space? weird either way)
    continue;
  fi

  file_dir="$MON_SECONDARY_STORAGE/$p_bin_name/$p_pid"

  if [ ! -d "$file_dir" ]; then
    # creating this directory for the fist time
    mkdir -p "$file_dir"
  fi

  # Log VSZ column value
  #===========================
  file_vsz="$file_dir/VSZ.csv";
  if [ ! -f "$file_vsz" ]; then
    # File does not exist, create it with header row
    printf "Date,Time,\"%s\"\r\n" "$p_name" > "$file_vsz"
  fi
  printf "%s,%s,%s\r\n" "$now_day" "$now_time" "$(echo "$line" | tr -s ' '| cut -d ' ' -f $num_VSZ)" >> "$file_vsz"

  # Log %VSZ column value
  #===========================
  file_vsz_percent="$file_dir/VSZ_percent.csv";
  if [ ! -f "$file_vsz_percent" ]; then
    # File does not exist, create it with header row
    printf "Date,Time,\"%s\"\r\n" "$p_name" > "$file_vsz_percent"
  fi
  tempv="$(echo "$line" | tr -s ' '| cut -d ' ' -f $num_PVSZ)%"
  printf "%s,%s,%s\r\n" "$now_day" "$now_time" "$(echo "$tempv" | tr -cd [:digit:])" >> "$file_vsz_percent"

  # Log %CPU column value
  #===========================
  file_cpu_percent="$file_dir/CPU_percent.csv";
  if [ ! -f "$file_cpu_percent" ]; then
    # File does not exist, create it with header row
    printf "Date,Time,\"%s\"\r\n" "$p_name" > "$file_cpu_percent"
  fi
  tempv="$(echo "$line" | tr -s ' '| cut -d ' ' -f $num_CPU)%"
  printf "%s,%s,%s\r\n" "$now_day" "$now_time" "$(echo "$tempv" | tr -cd [:digit:])" >> "$file_cpu_percent"
done
