#!/bin/sh

# Used to monitor processess
# VmRSS = progres (in vmstatus.sh) * 4 (the size of pages)) kB
# VmSize = totres (in vmstatus) * 4 (the size of pages) kB
# Name = processes name
# Pid = processes pid

# Secondary storage should point to /var/spool/storage/.../.../[FOLDER_NAME_VMSTATUS]
MON_SECONDARY_STORAGE="$1"

# ========================================
# Will now NOT support file retention
#file_name=$(date +"%Y%m%d_%H%M%S")
#file_name="$file_name.csv"
# ========================================
# Instead filename will always be:
file_name="vmstatus.csv"
# ========================================

now_day=$(date +"%Y-%m-%d")
now_time=$(date +"%H:%M:%S")

status_files=$(ls /proc/*/status)

for status_file in $status_files; do

	if [ ! -f $status_file ]; then
		continue;
	fi

	# Fetching the name of the process
	fetch=$(cat $status_file | grep "Name:")

	# If the first command failed, then there is no need to continue
	# processing this process. It does not have a status file for some reason.
	if [ ${#fetch} == 0 ]; then
		continue;
	fi

	fetch=${fetch#"Name:"}
	p_name=$(echo "$fetch" | cut -c 2-)

	# Fetching the PID
	fetch=$(cat $status_file | grep "^Pid:") # added ^ to incidate start of line to avoid partial matches
	p_pid=$(echo "$fetch" | tr -cd [:digit:])

	# Fetching the totres*(bytes per page) (VmSize) measured in kB
	fetch=$(cat $status_file | grep "VmSize:")
	p_totres=$(echo "$fetch" | tr -cd [:digit:])

	# Fetching the progres*(bytes per page) (VmRSS) measured in kB
	fetch=$(cat $status_file | grep "VmRSS:")
	p_progres=$(echo "$fetch" | tr -cd [:digit:])

	# It's time to store some status info!

	if [ ${#p_totres} == 0 ] || [ ${#p_progres} == 0 ] || [ ${#p_pid} == 0 ]; then
		# One or more of these numbers are missing, no reasons to continue.
		continue;
	fi

	if [ "$p_name" == "cat" ] || [ "$p_name" == "sh" ] || [ "$p_name" == "zip" ]  ; then
		# cat, sh or zip is used by this program and should not be considered
		continue;
	fi

	if [ ! -d "$MON_SECONDARY_STORAGE/$p_name/$p_pid" ]; then
		mkdir -p "$MON_SECONDARY_STORAGE/$p_name/$p_pid"
	fi

	# ==========================================================================================================
	# Will not not support file retention
	#echo "$now_day,$now_time,$p_progres,$p_totres" > "$MON_SECONDARY_STORAGE/$p_name/$p_pid/$file_name"
	# ==========================================================================================================
	if [ ! -f "$MON_SECONDARY_STORAGE/$p_name/$p_pid/$file_name" ]; then
		printf "Date,Time,Progres (kB),Totres (kB)\r\n" > "$MON_SECONDARY_STORAGE/$p_name/$p_pid/$file_name"
	fi

	printf "$now_day,$now_time,$p_progres,$p_totres\r\n" >> "$MON_SECONDARY_STORAGE/$p_name/$p_pid/$file_name"
done
